# Copyright (c) 2017, Camptocamp SA
# All rights reserved.

# Auto-generated file. Do not Edit!
INFO = {
    "git_hash": "5d88eaa384d2f6a67a6240127cbbd9e37c35628d",
    "version": "2.2",
    "git_tag": "2.2.0.dev8",
}
